@@ -46,22 +46,23 @@ sub load {
     require Config::Tiny;
     my $config = Config::Tiny->read( $file );
 
-    my $main = delete $config->{ _ };
-    my $out;
-    $out->{ $_ } = $main->{ $_ } for keys %$main;
+    die $Config::Tiny::errstr if not defined $config;
+
+    my $out = delete $config->{ _ } || {};
 
     for my $k ( keys %$config ) {
-        my @keys = split /\s+/, $k if $MAP_SECTION_SPACE_TO_NESTED_KEY;
+        my @keys = split /\s+/, $k;
         my $ref = $config->{ $k };
 
-        if ( @keys > 1 ) {
+        if ( $MAP_SECTION_SPACE_TO_NESTED_KEY && @keys > 1 ) {
             my ( $a, $b ) = @keys[ 0, 1 ];
             $out->{ $a }->{ $b } = $ref;
         }
         else {
-            $out->{ $k } = $ref;
+            $out->{ $k } = { %{ $out->{ $k } || {} }, %$ref };
         }
     }
+
     return $out;
 }
 
